==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/DefaultRolloutSpecificationMediumTrafficArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationMediumTrafficArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property regions
 * @property waitDuration
 */
public data class DefaultRolloutSpecificationMediumTrafficArgs(
    public val regions: Output<List<String>>? = null,
    public val waitDuration: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationMediumTrafficArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationMediumTrafficArgs =
        com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationMediumTrafficArgs.builder()
            .regions(regions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .waitDuration(waitDuration?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DefaultRolloutSpecificationMediumTrafficArgs].
 */
@PulumiTagMarker
public class DefaultRolloutSpecificationMediumTrafficArgsBuilder internal constructor() {
    private var regions: Output<List<String>>? = null

    private var waitDuration: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("romwqbcwiuljimqh")
    public suspend fun regions(`value`: Output<List<String>>) {
        this.regions = value
    }

    @JvmName("ccpnotqkuapjbqkn")
    public suspend fun regions(vararg values: Output<String>) {
        this.regions = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("ponqyifurpgrsroy")
    public suspend fun regions(values: List<Output<String>>) {
        this.regions = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("wnmcxbbpepbymsar")
    public suspend fun waitDuration(`value`: Output<String>) {
        this.waitDuration = value
    }

    /**
     * @param value
     */
    @JvmName("ftsldsshgfkgmima")
    public suspend fun regions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.regions = mapped
    }

    /**
     * @param values
     */
    @JvmName("bwtvjvrtohytxidd")
    public suspend fun regions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.regions = mapped
    }

    /**
     * @param value
     */
    @JvmName("npasqxpomdxisucw")
    public suspend fun waitDuration(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.waitDuration = mapped
    }

    internal fun build(): DefaultRolloutSpecificationMediumTrafficArgs =
        DefaultRolloutSpecificationMediumTrafficArgs(
            regions = regions,
            waitDuration = waitDuration,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/DefaultRolloutSpecificationMediumTrafficArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationMediumTrafficArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property regions
 * @property waitDuration
 */
public data class DefaultRolloutSpecificationMediumTrafficArgs(
    public val regions: Output<List<String>>? = null,
    public val waitDuration: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationMediumTrafficArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationMediumTrafficArgs =
        com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationMediumTrafficArgs.builder()
            .regions(regions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .waitDuration(waitDuration?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DefaultRolloutSpecificationMediumTrafficArgs].
 */
@PulumiTagMarker
public class DefaultRolloutSpecificationMediumTrafficArgsBuilder internal constructor() {
    private var regions: Output<List<String>>? = null

    private var waitDuration: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("rntavnyeqnttvmlx")
    public suspend fun regions(`value`: Output<List<String>>) {
        this.regions = value
    }

    @JvmName("jwtmavuqtxlgflop")
    public suspend fun regions(vararg values: Output<String>) {
        this.regions = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("yutvpggosavjcthc")
    public suspend fun regions(values: List<Output<String>>) {
        this.regions = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("ngnhphkthndwisdv")
    public suspend fun waitDuration(`value`: Output<String>) {
        this.waitDuration = value
    }

    /**
     * @param value
     */
    @JvmName("uiorxrisxakglwie")
    public suspend fun regions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.regions = mapped
    }

    /**
     * @param values
     */
    @JvmName("rlmhbyijignocypo")
    public suspend fun regions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.regions = mapped
    }

    /**
     * @param value
     */
    @JvmName("dcwabpufrpijxfqi")
    public suspend fun waitDuration(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.waitDuration = mapped
    }

    internal fun build(): DefaultRolloutSpecificationMediumTrafficArgs =
        DefaultRolloutSpecificationMediumTrafficArgs(
            regions = regions,
            waitDuration = waitDuration,
        )
}
